@@ -1,4 +1,5 @@
 import os
+import re
 import logging
 
 from mkdocs.plugins import BasePlugin
@@ -35,6 +36,7 @@ class PrintSitePlugin(BasePlugin):
         ("add_print_site_banner", config_options.Type(bool, default=True)),
         ("print_site_banner_template", config_options.Type(str, default="")),
         ("path_to_pdf", config_options.Type(str, default="")),
+        ("enabled", config_options.Type(bool, default=True)),
         ("exclude", config_options.Type(list, default=[])),
     )
 
@@ -44,6 +46,8 @@ class PrintSitePlugin(BasePlugin):
 
         See https://www.mkdocs.org/user-guide/plugins/#on_config.
         """
+        if not self.config.get("enabled"):
+            return config
         # Check valid table of contents depth
         assert self.config.get("toc_depth") >= 1
         assert self.config.get("toc_depth") <= 6
@@ -93,7 +97,6 @@ class PrintSitePlugin(BasePlugin):
 
         # Add pointer to print-site javascript
         config["extra_javascript"] = ["js/print-site.js"] + config["extra_javascript"]
-        config["extra_javascript"] = ["js/print-site-instant-loading.js"] + config["extra_javascript"]
 
         # Add pointer to theme specific css files
         file = "print-site-%s.css" % get_theme_name(config)
@@ -139,6 +142,9 @@ class PrintSitePlugin(BasePlugin):
         Can be used to alter the site navigation.
         See https://www.mkdocs.org/user-guide/plugins/#on_nav.
         """
+        if not self.config.get("enabled"):
+            return nav
+
         # Save the (order of) pages and sections in the navigation before adding the print page
         self.renderer.items = nav.items
 
@@ -156,10 +162,23 @@ class PrintSitePlugin(BasePlugin):
         (but before being passed to a template) and can be used to alter the HTML body of the page.
         See https://www.mkdocs.org/user-guide/plugins/#on_page_content.
         """
+        if not self.config.get("enabled"):
+            return html
+
         # Save each page HTML *before* a template is applied inside the page class
         if page != self.print_page:
             page.html = html
 
+        # We need to validate that the first heading on each page is a h1
+        # This is required for the print page table of contents and enumeration logic
+        if self.config.get("add_table_of_contents") or self.config.get("enumerate_headings"):
+            match = re.search(r"\<h[0-6]", html)
+            if match:
+                if not match.group() == "<h1":
+                    msg = f"The page {page.title} ({page.file.src_path}) does not start with a level 1 heading."
+                    msg += "This is required for print page Table of Contents and/or enumeration of headings."
+                    raise AssertionError(msg)
+
         # Link to the PDF version of the entire site on a page.
         if self.config.get("path_to_pdf") != "":
             page.url_to_pdf = get_relative_url(self.config.get("path_to_pdf"), page.file.url)
@@ -173,6 +192,9 @@ class PrintSitePlugin(BasePlugin):
         It can be used to alter the context for that specific page only.
         See https://www.mkdocs.org/user-guide/plugins/#on_page_context.
         """
+        if not self.config.get("enabled"):
+            return
+
         # Save the page context
         # We'll use the same context of the last rendered page
         # And apply it to the print page as well (in on_post_build event)
@@ -188,6 +210,9 @@ class PrintSitePlugin(BasePlugin):
 
         See https://www.mkdocs.org/user-guide/plugins/#on_post_build.
         """
+        if not self.config.get("enabled"):
+            return
+
         # Add print-site.js
         js_output_base_path = os.path.join(config["site_dir"], "js")
         js_file_path = os.path.join(js_output_base_path, "print-site.js")
